summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/com/android/browser/WebsiteSettingsActivity.java9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/com/android/browser/WebsiteSettingsActivity.java b/src/com/android/browser/WebsiteSettingsActivity.java
index 645e084..7166b16 100644
--- a/src/com/android/browser/WebsiteSettingsActivity.java
+++ b/src/com/android/browser/WebsiteSettingsActivity.java
@@ -512,6 +512,10 @@ public class WebsiteSettingsActivity extends ListActivity {
notifyDataSetChanged();
}
}
+
+ public Site currentSite() {
+ return mCurrentSite;
+ }
}
/**
@@ -548,8 +552,9 @@ public class WebsiteSettingsActivity extends ListActivity {
@Override
public boolean onPrepareOptionsMenu(Menu menu) {
- // If we aren't listing any sites hide the clear all button (and hence the menu).
- return mAdapter.getCount() > 0;
+ // If we are not on the sites list (rather on the page for a specific site) or
+ // we aren't listing any sites hide the clear all button (and hence the menu).
+ return mAdapter.currentSite() == null && mAdapter.getCount() > 0;
}
@Override